@@ -80,7 +80,7 @@ class MultipleFormatResponseMixin(TemplateResponseMixin):
 
     #: Templates por formato
     templates = {
-        'html': 'base/base.html',
+        'html': 'page.example.html',
     }
 
     #: Determina si se tiene que redireccionar.
